@@ -10,7 +10,7 @@ function clean(string $value, bool $allowHTML = false): ?string
     $value = trim($value);
 
     if (!$allowHTML) {
-        $value = html_entity_decode($value);
+        $value = html_entity_decode($value, ENT_QUOTES | ENT_SUBSTITUTE | ENT_HTML401);
         $value = strip_tags($value);
     }
 
@@ -140,7 +140,7 @@ function getDirectory(string $path, int $position): ?string
  *
  * @return boolean
  */
-function isEmpty(mixed ...$values): bool
+function isEmpty(...$values): bool
 {
     $skipValues = array(
         'undefined',
@@ -154,3 +154,25 @@ function isEmpty(mixed ...$values): bool
 
     return false;
 }
+
+if (!function_exists("array_is_list")) {
+    /**
+     * Polyfil for https://www.php.net/manual/en/function.array-is-list.php
+     * which is only available in PHP 8.1+
+     *
+     * @param      array  $array  The array
+     *
+     * @return     bool
+     */
+    function array_is_list(array $array): bool
+    {
+        $i = -1;
+        foreach ($array as $k => $v) {
+            ++$i;
+            if ($k !== $i) {
+                return false;
+            }
+        }
+        return true;
+    }
+}
